@@ -313,7 +313,7 @@ void Engine::set_midi_bridge (MidiBridge * bridge)
 		_midi_bridge->MidiControlEvent.connect (mem_fun(*this, &Engine::push_midi_control_event));
 		_midi_bridge->MidiSyncEvent.connect (mem_fun(*this, &Engine::push_sync_event));
 
-		ParamChanged.connect(bind (mem_fun(*_midi_bridge, &MidiBridge::parameter_changed), this));
+		ParamChanged.connect(sigc::bind(mem_fun(*_midi_bridge, &MidiBridge::parameter_changed), this));
 
 		_midi_bridge->set_output_midi_clock(_output_midi_clock);
 	}
@@ -1283,7 +1283,9 @@ Engine::push_midi_command_event (Event::type_t type, Event::command_t cmd, int8_
 bool
 Engine::do_push_command_event (RingBuffer<Event> * evqueue, Event::type_t type, Event::command_t cmd, int8_t instance, long framepos)
 {
-	// todo support more than one simulataneous pusher safely
+    if (!is_ok()) return false;
+    
+    // todo support more than one simulataneous pusher safely
 	RingBuffer<Event>::rw_vector vec;
 
 	evqueue->get_write_vector (&vec);
@@ -1312,6 +1314,7 @@ bool
 Engine::do_push_control_event (RingBuffer<Event> * evqueue, Event::type_t type, Event::control_t ctrl, float val, int8_t instance, long framepos, int src)
 {
 	// todo support more than one simulataneous pusher safely
+    if (!is_ok()) return false;
 
 	RingBuffer<Event>::rw_vector vec;
 
@@ -1374,6 +1377,8 @@ Engine::push_midi_control_event (Event::type_t type, Event::control_t ctrl, floa
 void
 Engine::push_sync_event (Event::control_t ctrl, long framepos, MIDI::timestamp_t timestamp)
 {
+    if (!is_ok()) return;
+
 	// todo support more than one simulataneous pusher safely
 
 	if (_sync_source != MidiClockSync 
@@ -1537,12 +1542,39 @@ Engine::get_control_value (Event::control_t ctrl, int8_t instance)
 		else if (ctrl == Event::JackTimebaseMaster) {
 			return _jack_timebase_master ? 1.0f: 0.0f;
 		}
+		else if (ctrl == Event::GlobalCycleLen) {
+			return _tempo_frames / _driver->get_samplerate();
+		}
+		else if (ctrl == Event::GlobalCyclePos) {
+			return _tempo_counter / _driver->get_samplerate();
+		}
 
 	}
 
 	return 0.0f;
 }
 
+std::string 
+Engine::get_property_value (std::string prop, int8_t instance)
+{
+	if (instance >= 0 && instance < (int) _instances.size()) {
+		if (prop == "name") {
+			return _instances[instance]->get_name();
+		}
+	}
+	return {};
+}
+
+void 
+Engine::set_property_value (std::string prop, int8_t instance, std::string value)
+{
+	if (instance >= 0 && instance < (int) _instances.size()) {
+		if (prop == "name") {
+			_instances[instance]->set_name(value);
+		}
+	}
+}
+
 
 bool
 Engine::push_nonrt_event (EventNonRT * event)
@@ -1795,6 +1827,8 @@ Engine::process_nonrt_event (EventNonRT * event)
 {
 	ConfigUpdateEvent * cu_event;
 	GetParamEvent *     gp_event;
+	GetPropertyEvent *  gprop_event;
+	SetPropertyEvent *  sprop_event;
 	ConfigLoopEvent *   cl_event;
 	PingEvent *         ping_event;
 	RegisterConfigEvent * rc_event;
@@ -1811,6 +1845,15 @@ Engine::process_nonrt_event (EventNonRT * event)
 		gp_event->ret_value = get_control_value (gp_event->control, gp_event->instance);
 		_osc->finish_get_event (*gp_event);
 	}
+	else if ((gprop_event = dynamic_cast<GetPropertyEvent*> (event)) != 0)
+	{
+		gprop_event->ret_value = get_property_value (gprop_event->property, gprop_event->instance);
+		_osc->finish_get_property_event (*gprop_event);
+	}
+	else if ((sprop_event = dynamic_cast<SetPropertyEvent*> (event)) != 0)
+	{
+		set_property_value (sprop_event->property, sprop_event->instance, sprop_event->value);
+	}
 	else if ((gg_event = dynamic_cast<GlobalGetEvent*> (event)) != 0)
 	{
 		if (gg_event->param == "dry") {
@@ -2598,7 +2641,9 @@ Engine::generate_sync (nframes_t offset, nframes_t nframes)
 			if (_quarter_note_frames > 0.0) {
 				nframes_t currpos  = (nframes_t) (_rt_instances[_sync_source-1]->get_control_value(Event::LoopPosition) * _driver->get_samplerate());
 				nframes_t loopframes = (nframes_t) (_rt_instances[_sync_source-1]->get_control_value(Event::LoopLength) * _driver->get_samplerate());
-				if (loopframes > 0) {
+				int inst_stt = (int)(_rt_instances[_sync_source-1]->get_control_value(Event::State));
+				bool inst_paused = (inst_stt == LooperStateOff || inst_stt == LooperStatePaused || inst_stt == LooperStateOffMuted);
+				if ((loopframes > 0) && !inst_paused) {
 					nframes_t testval = (((currpos + nframes) % loopframes) % (nframes_t)_quarter_note_frames);
 					
 					if (testval <= nframes || testval == 0) {
