@@ -122,15 +122,21 @@ namespace SooperLooper {
 		    RECORD_SOLO_PREV,
 		    SET_SYNC_POS,
 		    RESET_SYNC_POS,
-			MUTE_TRIGGER,
+			  MUTE_TRIGGER,
 		    RECORD_OR_OVERDUB,
-			RECORD_EXCLUSIVE,
-			RECORD_EXCLUSIVE_NEXT,
-			RECORD_EXCLUSIVE_PREV,
-			RECORD_OR_OVERDUB_EXCL,
-			RECORD_OR_OVERDUB_EXCL_NEXT,
-			RECORD_OR_OVERDUB_EXCL_PREV,
-			UNDO_TWICE,
+			  RECORD_EXCLUSIVE,
+			  RECORD_EXCLUSIVE_NEXT,
+			  RECORD_EXCLUSIVE_PREV,
+			  RECORD_OR_OVERDUB_EXCL,
+			  RECORD_OR_OVERDUB_EXCL_NEXT,
+			  RECORD_OR_OVERDUB_EXCL_PREV,
+			  UNDO_TWICE,
+		    RECORD_OR_OVERDUB_SOLO,
+		    RECORD_OR_OVERDUB_SOLO_TRIG,
+		    RECORD_OVERDUB_END_SOLO,
+		    RECORD_OVERDUB_END_SOLO_TRIG,
+		    RECORD_OR_OVERDUB_SOLO_NEXT,
+		    RECORD_OR_OVERDUB_SOLO_PREV,
 		    LAST_COMMAND
 	    } Command;
 
@@ -213,7 +219,10 @@ namespace SooperLooper {
 		    PanChannel4,
 		    // Put all new controls at the end to avoid screwing up the order of existing AU sessions (who store these numbers)
 		    ReplaceQuantized,
-		    SendMidiStartOnTrigger
+		    SendMidiStartOnTrigger,
+		    DiscretePreFader,
+		    GlobalCycleLen,
+		    GlobalCyclePos
 	    } Control;
 	    
 	    int8_t  Instance;
