@@ -142,6 +142,8 @@ AppFrame::AppFrame(const wxString& title, const wxPoint& pos, const wxSize& size
 
 AppFrame::~AppFrame()
 {
+	get_main_panel()->set_default_position(GetScreenPosition());
+                
 	_mainpanel->save_rc();
     
     //wxLogWarning(wxT("appframe destroy"));
@@ -159,11 +161,8 @@ AppFrame::init()
 	
 	wxFont sliderFont = *wxSMALL_FONT;
 
-	
 	_mainpanel = new MainPanel(this, -1, wxDefaultPosition, wxDefaultSize);
 
-	_mainpanel->PreferredSizeChange.connect (mem_fun (*this,  &AppFrame::on_preferred_size));
-
 	_mainpanel->set_force_local(_embedded);
 	
     if (!_embedded) {
@@ -185,13 +184,14 @@ AppFrame::init()
         menuFile->Append(ID_RemoveLoop, wxT("Remove Last Loop\tCtrl-D"), wxT("Remove last loop"));
         
         menuFile->AppendSeparator();
-        menuFile->Append(ID_PreferencesMenu, wxT("&Preferences...\tCtrl-P"), wxT("Preferences..."));
+
+        menuFile->Append(ID_PreferencesMenu, wxT("&Preferences...\tCtrl-,"), wxT("Preferences..."));
         
 #ifndef __WXMAC__
         menuFile->AppendSeparator();
 #endif
         
-        menuFile->Append(ID_Quit, wxT("Quit but Leave Engine Running\tCtrl-Shift-Q"), wxT("Exit from GUI and leave engine running"));
+        menuFile->Append(ID_Quit, wxT("Quit but Leave Engine Running\tCtrl-Alt-Q"), wxT("Exit from GUI and leave engine running"));
         menuFile->Append(ID_QuitStop, wxT("Quit and Stop Engine\tCtrl-Q"), wxT("Exit from GUI and stop engine"));
         
         menuBar->Append(menuFile, wxT("&Session"));
@@ -245,12 +245,8 @@ AppFrame::init()
 
 
     _topsizer->Add (_mainpanel, 1, wxEXPAND);
-
-	
-	this->SetAutoLayout( true );     // tell dialog to use sizer
-	this->SetSizer( _topsizer );      // actually set the sizer
-	_topsizer->Fit( this );            // set size to minimum size as calculated by the sizer
-	_topsizer->SetSizeHints( this );   // set size hints to honour mininum size
+    
+    SetSizerAndFit(_topsizer);
 }
 
 
@@ -268,29 +264,6 @@ AppFrame::OnActivate(wxActivateEvent &ev)
 	
 }
 
-void
-AppFrame::on_preferred_size(int w, int h)
-{
-	int topheight = 0;
-#ifndef __WXMAC__
-	if (GetMenuBar()) {
-		topheight += GetMenuBar()->GetSize().GetHeight();
-	}
-#else
-	topheight += 32;
-
-    if (_embedded && _toolbar) {
-        topheight += _toolbar->GetSize().GetHeight();
-    }
-
-#endif
-
-	//if (!_embedded) {
-        SetSize (w, h + topheight);
-    //}
-}
-
-
 void
 AppFrame::OnClose(wxCloseEvent &event)
 {
