@@ -26,7 +26,7 @@
 #include <string>
 #include <vector>
 
-#include <sigc++/object.h>
+#include <sigc++/trackable.h>
 #include <sigc++/signal.h>
 #include <sigc++/connection.h>
 
@@ -67,8 +67,6 @@ public:
 protected:
 
 	void init();
-
-	void on_preferred_size(int w, int h);
 	
 	void on_add_loop (wxCommandEvent &ev);
 	void on_add_custom_loop (wxCommandEvent &ev);
