@@ -42,7 +42,8 @@ LoopControl::SpawnConfig::SpawnConfig(const wxString & nm)
 	: name(nm), host(""), port(DEFAULT_OSC_PORT), num_loops(1), num_channels(2),
 	  mem_secs(40.0f), discrete_io(true), exec_name("sooperlooper"), midi_bind_path(""), force_spawn(false), never_spawn(false),
 	  never_timeout(false),
-	  jack_name("")
+	  jack_name(""),
+          window_x_pos(100), window_y_pos(100)
 {
 }
 
@@ -78,7 +79,8 @@ XMLNode& LoopControl::SpawnConfig::get_state () const
 
 	node->add_property ("force_spawn", force_spawn ? "yes": "no");
 	node->add_property ("never_timeout", never_timeout ? "yes": "no");
-	
+
+
 	return *node;
 }
 
@@ -145,6 +147,7 @@ int LoopControl::SpawnConfig::set_state (const XMLNode& node)
 					force_spawn = false;
 				}
 			}
+                        
 			/*
 			if ((prop = child_node->property ("never_timeout")) != 0) {
 				if (prop->value() == "yes") {
@@ -191,6 +194,7 @@ LoopControl::LoopControl (const wxString & rcdir)
 	
 	/* add handler for control param callbacks, first is loop index , 2nd arg ctrl string, 3nd arg value */
 	lo_server_add_method(_osc_server, "/ctrl", "isf", LoopControl::_control_handler, this);
+	lo_server_add_method(_osc_server, "/prop", "iss", LoopControl::_property_handler, this);
 
 	// pingack expects: s:engine_url s:version i:loopcount
 	lo_server_add_method(_osc_server, "/pingack", "ssi", LoopControl::_pingack_handler, this);
@@ -318,7 +322,8 @@ LoopControl::connect()
 	// if the spawn_config host string is 127.0.0.1 or localhost, make our_url match it
 	if (_spawn_config.host == "127.0.0.1" || _spawn_config.host == "localhost") {
 		char tmpbuf[100];
-		snprintf (tmpbuf, sizeof(tmpbuf), "osc.udp://localhost:%d/", _our_port);
+		//snprintf (tmpbuf, sizeof(tmpbuf), "osc.udp://localhost:%d/", _our_port);
+                snprintf (tmpbuf, sizeof(tmpbuf), "osc.udp://127.0.0.1:%d/", _our_port);
 		_our_url = tmpbuf;
 		cerr << "Changing our url to be : " << _our_url << endl;
 	}
@@ -332,12 +337,12 @@ LoopControl::connect()
 		// send off a ping.  set a timer, if we don't have a response, we'll start our own locally
 		_waiting = 0;
 		lo_send(_osc_addr, "/ping", "ssi", _our_url.c_str(), "/pingack", 1);
-		//cerr << "sending ping" << endl;
+		//cerr << "sending initial ping" << endl;
 		_updatetimer->Start(700, true);
 	}
 	// spawn now
 	else if (!_spawn_config.never_spawn && spawn_looper()) {
-		//cerr << "immediate spawn" << endl;
+            //cerr << "immediate spawn" << endl;
 		_waiting = 1;
 		_updatetimer->Start(100, true);
 	}
@@ -381,10 +386,14 @@ LoopControl::register_global_updates(bool unreg)
 	if (unreg) {
 		lo_send(_osc_addr, "/unregister_auto_update", "siss", "in_peak_meter", 100, _our_url.c_str(), "/ctrl");
 		lo_send(_osc_addr, "/unregister_auto_update", "siss", "out_peak_meter", 100, _our_url.c_str(), "/ctrl");
+		lo_send(_osc_addr, "/unregister_auto_update", "siss", "global_cycle_len", 100, _our_url.c_str(), "/ctrl");
+		lo_send(_osc_addr, "/unregister_auto_update", "siss", "global_cycle_pos", 100, _our_url.c_str(), "/ctrl");
 	}
 	else {
 		lo_send(_osc_addr, "/register_auto_update", "siss", "in_peak_meter", 100, _our_url.c_str(), "/ctrl");
 		lo_send(_osc_addr, "/register_auto_update", "siss", "out_peak_meter", 100, _our_url.c_str(), "/ctrl");
+		lo_send(_osc_addr, "/register_auto_update", "siss", "global_cycle_len", 100, _our_url.c_str(), "/ctrl");
+		lo_send(_osc_addr, "/register_auto_update", "siss", "global_cycle_pos", 100, _our_url.c_str(), "/ctrl");
 	}
 }
 
@@ -509,7 +518,7 @@ LoopControl::pingtimer_expired()
 	// check state of pingack
 
 	if (_pingack) {
-		// cerr << "got ping response" << endl;
+		 cerr << "got ping response" << endl;
 	}
 	else if (_waiting > 0)
 	{
@@ -544,9 +553,11 @@ LoopControl::pingtimer_expired()
 			}
 		}
 		else {
-			// cerr << "waiting" << endl;
+                    //cerr << "waiting " << _waiting << endl;
 			_waiting++;
-			// lo_send(_osc_addr, "/ping", "ss", _our_url.c_str(), "/pingack");
+                        if (_waiting == 1 || (_waiting % 2) == 0) {
+                            lo_send(_osc_addr, "/ping", "ssi", _our_url.c_str(), "/pingack", 1);
+                        }
 			_updatetimer->Start(100, true);
 		}
 	}
@@ -845,6 +856,42 @@ LoopControl::control_handler(const char *path, const char *types, lo_arg **argv,
 	return 0;
 }
 
+int
+LoopControl::_property_handler(const char *path, const char *types, lo_arg **argv, int argc,
+			      void *data, void *user_data)
+{
+	LoopControl * lc = static_cast<LoopControl*> (user_data);
+	return lc->property_handler (path, types, argv, argc, data);
+}
+
+
+int
+LoopControl::property_handler(const char *path, const char *types, lo_arg **argv, int argc, void *data)
+{
+// loop instance is 1st arg, 2nd is ctrl string, 3rd is float value
+
+	int  index = argv[0]->i;
+	wxString prop = wxString::FromAscii(&argv[1]->s);
+	wxString val  = wxString::FromAscii(&argv[2]->s);
+
+	// cerr << "got prop " << prop.ToAscii() << " = " << val.ToAscii() << "  index=" << index << endl;
+
+	if (index >= (int) _properties_val_map.size()) {
+		_properties_val_map.resize(index + 1);
+		_updated.resize(index + 1);
+	}
+
+	if (_properties_val_map[index].find(prop) == _properties_val_map[index].end()
+	    || _properties_val_map[index][prop] != val)
+	{
+		_updated[index][prop] = true;
+	}
+
+	_properties_val_map[index][prop] = val;
+
+	return 0;
+}
+
 int
 LoopControl::_midi_binding_handler(const char *path, const char *types, lo_arg **argv, int argc,
 			      void *data, void *user_data)
@@ -994,6 +1041,7 @@ LoopControl::request_all_values(int index)
 	lo_send(_osc_addr, buf, "sss", "output_latency", _our_url.c_str(), "/ctrl");
 	lo_send(_osc_addr, buf, "sss", "trigger_latency", _our_url.c_str(), "/ctrl");
 	lo_send(_osc_addr, buf, "sss", "autoset_latency", _our_url.c_str(), "/ctrl");
+    lo_send(_osc_addr, buf, "sss", "discrete_prefader", _our_url.c_str(), "/ctrl");
 	lo_send(_osc_addr, buf, "sss", "mute_quantized", _our_url.c_str(), "/ctrl");
 	lo_send(_osc_addr, buf, "sss", "overdub_quantized", _our_url.c_str(), "/ctrl");
 	lo_send(_osc_addr, buf, "sss", "replace_quantized", _our_url.c_str(), "/ctrl");
@@ -1006,6 +1054,9 @@ LoopControl::request_all_values(int index)
 	lo_send(_osc_addr, buf, "sss", "pan_3", _our_url.c_str(), "/ctrl");
 	lo_send(_osc_addr, buf, "sss", "pan_4", _our_url.c_str(), "/ctrl");
 
+	snprintf(buf, sizeof(buf), "/sl/%d/get_prop", index);
+	lo_send(_osc_addr, buf, "sss", "name", _our_url.c_str(), "/prop");
+
 }
 
 void
@@ -1232,6 +1283,7 @@ LoopControl::register_input_controls(int index, bool unreg)
 	lo_send(_osc_addr, buf, "sss", "output_latency", _our_url.c_str(), "/ctrl");
 	lo_send(_osc_addr, buf, "sss", "trigger_latency", _our_url.c_str(), "/ctrl");
 	lo_send(_osc_addr, buf, "sss", "autoset_latency", _our_url.c_str(), "/ctrl");
+    lo_send(_osc_addr, buf, "sss", "discrete_prefader", _our_url.c_str(), "/ctrl");
 	lo_send(_osc_addr, buf, "sss", "mute_quantized", _our_url.c_str(), "/ctrl");
 	lo_send(_osc_addr, buf, "sss", "overdub_quantized", _our_url.c_str(), "/ctrl");
 	lo_send(_osc_addr, buf, "sss", "replace_quantized", _our_url.c_str(), "/ctrl");
@@ -1364,6 +1416,27 @@ LoopControl::post_global_ctrl_change (wxString ctrl, float val)
 	return true;
 }
 
+bool
+LoopControl::post_property_change (int index, wxString ctrl, wxString val)
+{
+	if (!_osc_addr) return false;
+	char buf[50];
+
+	// go ahead and update our local copy
+	if (index >= 0 && index < (int) _properties_val_map.size()) {
+		_properties_val_map[index][ctrl] = val;
+	}
+
+	snprintf(buf, sizeof(buf), "/sl/%d/set_prop", index);
+
+	if (lo_send(_osc_addr, buf, "ss", (const char *) ctrl.ToAscii(), (const char *) val.ToAscii()) == -1) {
+		return false;
+	}
+
+	return true;
+}
+
+
 bool
 LoopControl::post_save_loop(int index, wxString fname, wxString format, wxString endian)
 {
@@ -1501,6 +1574,26 @@ LoopControl::get_value (int index, wxString ctrl, float & retval)
 	return ret;
 }
 
+bool
+LoopControl::get_property (int index, wxString prop, wxString & retval)
+{
+	bool ret = false;
+	
+	if (index >= 0 && index < (int) _properties_val_map.size())
+	{
+		PropertyValMap::iterator iter = _properties_val_map[index].find (prop);
+
+		if (iter != _properties_val_map[index].end()) {
+			retval = (*iter).second;
+			// set updated to false
+			_updated[index][prop] = false;
+			ret = true;
+		}
+	}
+
+	return ret;
+}
+
 
 bool
 LoopControl::is_global_updated (wxString ctrl)
