@@ -26,7 +26,7 @@
 #include <string>
 #include <vector>
 
-#include <sigc++/object.h>
+#include <sigc++/trackable.h>
 #include <sigc++/signal.h>
 #include <sigc++/connection.h>
 
@@ -95,16 +95,20 @@ public:
 	bool load_rc();
 	bool save_rc();
 
+        wxPoint get_default_position() const { return _default_position; }
+        void set_default_position(wxPoint pos) { _default_position = pos; }
+    
 	void set_never_timeout(bool flag);
 	bool get_never_timeout() const { return _never_timeout; }
 
 	void save_default_midibindings ();
 
 	wxString do_file_selector(const wxString & message, const wxString & ext, const wxString & wc, int style);
-	
-	sigc::signal2<void,int, int> PreferredSizeChange;
 
-	
+    void set_sliders_allow_mousewheel (bool flag);
+    bool get_sliders_allow_mousewheel () const { return _sliders_allow_mousewheel; }
+
+
 protected:
 
 	void init();
@@ -172,7 +176,7 @@ protected:
 	wxTimer * _taptempo_button_timer;
 
 	wxScrolledWindow * _scroller;
-	wxBoxSizer * _main_sizer;
+	wxBoxSizer * _scroller_sizer;
 	wxBoxSizer * _topsizer;
 	wxPanel    * _top_panel;
 
@@ -201,6 +205,7 @@ protected:
     float _add_secs_channel;
     bool _add_discrete;
     
+    wxPoint _default_position;
     
 	// keybindings
 
@@ -218,6 +223,8 @@ protected:
 
 	wxString      _last_used_path;
 
+    bool _sliders_allow_mousewheel;
+
 private:
     // any class wishing to process wxWindows events must use this macro
     DECLARE_EVENT_TABLE()
